# -*- coding: utf-8; -*-
################################################################################
#
#  Rattail -- Retail Software Framework
#  Copyright © 2010-2024 Lance Edgar
#
#  This file is part of Rattail.
#
#  Rattail is free software: you can redistribute it and/or modify it under the
#  terms of the GNU General Public License as published by the Free Software
#  Foundation, either version 3 of the License, or (at your option) any later
#  version.
#
#  Rattail is distributed in the hope that it will be useful, but WITHOUT ANY
#  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
#  details.
#
#  You should have received a copy of the GNU General Public License along with
#  Rattail.  If not, see <http://www.gnu.org/licenses/>.
#
################################################################################
"""
Theo commands
"""

import typer

from rattail.commands.typer import typer_callback


# nb. this is the top-level command for corporal
theo_typer = typer.Typer(
    callback=typer_callback,
    help="Theo, the order system"
)


@theo_typer.command()
def install(
        ctx: typer.Context,
):
    """
    Install the Theo app
    """
    from rattail.install import InstallHandler

    config = ctx.parent.rattail_config
    handler = InstallHandler(config,
                             app_title="Theo",
                             app_package='theo',
                             app_eggname='tailbone_theo',
                             app_pypiname='tailbone-theo')
    handler.run()
